<?php

/**
 * @file
 * Contains Drupal\social_simple\Form\SocialSimple.
 */

namespace Drupal\social_simple\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\node\Entity\NodeType;
use Drupal\Core\Config\ConfigFactoryInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Drupal\Core\entity\EntityFieldManager;

/**
 * Class SocialSimple.
 *
 * @package Drupal\social_simple\Form
 */
class SocialSimple extends ConfigFormBase {

  /**
   * Constructs a \Drupal\system\ConfigFormBase object.
   *
   * @param \Drupal\Core\Config\ConfigFactoryInterface $config_factory
   *   The factory for configuration objects.
   */
  public function __construct(ConfigFactoryInterface $config_factory, EntityFieldManager $entity_field_manager) {
    parent::__construct($config_factory);
    $this->entityFieldManager = $entity_field_manager;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('config.factory'),
      $container->get('entity_field.manager')
    );
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return [
      'social_simple.settings',
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'social_simple_settings';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $config = $this->config('social_simple.settings');

    $form['intro'] = array(
      '#markup' => '<h3 class="messages messages--warning">' . $this->t('Under development...') . '</h3>',
    );

    $form['twitter'] = array(
      '#type' => 'details',
      '#title' => $this->t('Twitter configuration'),
      '#tree' => TRUE,
      '#open' => TRUE,
    );

    $valid_field_type = ['entity_reference', 'string'];
    foreach (NodeType::loadMultiple() as $bundle) {
      $options = [];
      $fields = $this->entityFieldManager->getFieldDefinitions('node', $bundle->id());
      /** @var \Drupal\Core\Field\BaseFieldDefinition $field */
      foreach ($fields as $name => $field) {
        if (!empty($field->getTargetBundle()) && in_array($field->getType(), $valid_field_type)) {
          $options[$name] = $field->getLabel();
        }
      }

      $form['twitter'][$bundle->id()]['hashtag'] = [
        '#type' => 'select',
        '#title' => $this->t('Hashtags for Content type :bundle', [':bundle' => $bundle->label()]),
        '#description' => $this->t('Select the field which provide hashtags. Leave empty if you do not want provide hahtags for this content type'),
        '#options' => ['none' => $this->t('- None -')] + $options,
        '#default_value' => $config->get($bundle->id() . '.hashtag'),
      ];
    }

    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function validateForm(array &$form, FormStateInterface $form_state) {
    parent::validateForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    parent::submitForm($form, $form_state);

    foreach (NodeType::loadMultiple() as $bundle) {
      $value = $form_state->getValue(['twitter', $bundle->id(), 'hashtag']);
      $this->config('social_simple.settings')
        ->set($bundle->id(), ['hashtag' => $value])
        ->save();
    }

  }

}
