<?php

namespace Drupal\social_simple;

use Drupal\Core\Entity\EntityInterface;

/**
 * Interface SocialSimpleGeneratorInterface.
 *
 * @package Drupal\social_simple
 */
interface SocialSimpleGeneratorInterface {

  /**
   * Return an array of social networks supported.
   *
   * @return array $networks
   *   An array of social networks supported.
   */
  public function getNetworks();

  /**
   * Build the render array of social share links.
   *
   * @param array $networks
   *   An array of social network name keyed with network id.
   * @param string $title
   *   The title to use for the share links.
   * @param \Drupal\Core\Entity\EntityInterface $entity
   *   The entity if provided.
   *
   * @return array $links
   *   An array of social share links.
   */
  public function buildSocialLinks(array $networks, $title, EntityInterface $entity = NULL);

  /**
   * Build the social share links.
   *
   * @param array $networks
   *   An array of social network name keyed with network id.
   * @param \Drupal\Core\Entity\EntityInterface $entity
   *   The entity if provided.
   *
   * @return array $links
   *   An array of social share links.
   */
  public function generateSocialLinks(array $networks, EntityInterface $entity = NULL);

  /**
   * Build a social share link.
   *
   * @param string $network_id
   *   The network id.
   * @param string $network_name
   *   The network name.
   * @param string $title
   *   The title to share.
   * @param string $share_url
   *   The url to share.
   *
   * @return array $link
   *   The render array for a share link.
   */
  public function generateSocialLink($network_id, $network_name, $title, $share_url);

  /**
   * Get the title to share.
   *
   * @param \Drupal\Core\Entity\EntityInterface $entity
   *   The entity if provided.
   *
   * @return string $title
   *   The entity title or page title to share.
   */
  public function getTitle(EntityInterface $entity = NULL);

  /**
   * Get the share url.
   *
   * @param \Drupal\Core\Entity\EntityInterface $entity
   *   The entity if provided.
   *
   * @return string $url
   *   The url to share.
   */
  public function getShareUrl(EntityInterface $entity = NULL);

  /**
   * Get common attributes for the share link.
   *
   * @param string $network_name
   *   The social network name.
   *
   * @return array $attributes
   *   an array of link attributes.
   */
  public function getLinkAttributes($network_name);

}
